@@ -69,7 +69,7 @@ class LabelNotSupported(StorageModelError):
     pass
 
 
-CHECK_CONDITIONS_TO_CHECK = [
+_CHECK_CONDITIONS_TO_CHECK = [
     # 2-tuple of (sense_key, additional_sense_code)
     ('UNIT_ATTENTION', 'POWER ON OCCURRED'),
     ('UNIT_ATTENTION', 'REPORTED LUNS DATA HAS CHANGED'),
@@ -81,26 +81,29 @@ CHECK_CONDITIONS_TO_CHECK = [
     ('ABORTED_COMMAND', 'COMMANDS CLEARED BY DEVICE SERVER'),
 ]
 
-def safe_repr(obj):
+def _safe_repr(obj):
     try:
         return repr(obj)
     except:
         return object.__repr__(obj)
 
 def check_for_scsi_errors(func):
+    """
+    A decorator for catching SCSI errors from the `infi.asi` layer and converting them to storagemodel errors.
+    """
     from infi.asi.errors import AsiOSError, AsiSCSIError, AsiCheckConditionError, AsiRequestQueueFullError
     from sys import exc_info
     @wraps(func)
     def callable(*args, **kwargs):
         try:
             device = args[0]
-            logger.debug("Sending SCSI command {!r} for device {!r}".format(func, safe_repr(device)))
+            logger.debug("Sending SCSI command {!r} for device {!r}".format(func, _safe_repr(device)))
             response = func(*args, **kwargs)
             logger.debug("Got response {!r}".format(response))
             return response
         except AsiCheckConditionError, e:
             if not e.sense_obj:
-                msg = "got no sense from device {!r} during {!r}".format(safe_repr(device), func)
+                msg = "got no sense from device {!r} during {!r}".format(_safe_repr(device), func)
                 logger.error(msg, exc_info=exc_info())
                 raise chain(DeviceDisappeared(msg))
             (key, code) = (e.sense_obj.sense_key, e.sense_obj.additional_sense_code.code_name)
@@ -110,15 +113,15 @@ def check_for_scsi_errors(func):
                 raise chain(RescanIsNeeded(msg))
             raise
         except AsiRequestQueueFullError, e:
-            msg = "got queue full from device {!r} during {!r}".format(safe_repr(device), func)
+            msg = "got queue full from device {!r} during {!r}".format(_safe_repr(device), func)
             logger.debug(msg)
             raise chain(RescanIsNeeded(msg))
         except AsiSCSIError as error:
-            msg = "device {!r} disappeared during {!r}: {}".format(safe_repr(device), func, error)
+            msg = "device {!r} disappeared during {!r}: {}".format(_safe_repr(device), func, error)
             logger.error(msg)
             raise chain(DeviceDisappeared(msg))
         except (IOError, OSError, AsiOSError), error:
-            msg = "device {!r} disappeared during {!r}".format(safe_repr(device), func)
+            msg = "device {!r} disappeared during {!r}".format(_safe_repr(device), func)
             logger.error(msg, exc_info=exc_info())
             raise chain(DeviceDisappeared(msg))
     return callable
